package imt;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertThrows;

import java.util.Set;

import org.junit.jupiter.api.Test;

public class ConcoursTest {
	Jury jury1 = new Jury(1, "nom1", "prenom1", "06", Genre.HOMME);
	Jury jury2 = new Jury(2, "nom2", "prenom2", "06", Genre.HOMME);
	Jury jury3 = new Jury(3, "nom3", "prenom3", "06", Genre.HOMME);

	Chef chef1 = new Chef(1, "chef1", "prenomchef1", "07", Genre.HOMME, 2, Specialite.PATISSIER,
			Set.of(new Plat("plat1")));
	Chef chef2 = new Chef(2, "chef2", "prenomchef2", "07", Genre.HOMME, 2, Specialite.PATISSIER,
			Set.of(new Plat("plat2")));
	Chef chef3 = new Chef(3, "chef3", "prenomchef3", "07", Genre.HOMME, 2, Specialite.PATISSIER,
			Set.of(new Plat("plat3")));
	Chef chef4 = new Chef(4, "chef4", "prenomchef4", "07", Genre.HOMME, 2, Specialite.PATISSIER,
			Set.of(new Plat("plat4")));
	Chef chef5 = new Chef(5, "chef5", "prenomchef5", "07", Genre.HOMME, 2, Specialite.PATISSIER,
			Set.of(new Plat("plat5")));

	@Test
	void concours_trois_jurys_cinq_chefs() {
		var propositions = Set.of(
				new Proposition(new Plat("plat1"), chef1),
				new Proposition(new Plat("plat2"), chef2),
				new Proposition(new Plat("plat3"), chef3),
				new Proposition(new Plat("plat4"), chef4));

		assertThrows(IllegalArgumentException.class, () -> new Concours(jury1, jury2, jury3, propositions));
	}

	@Test
	void les_chefs_proposent_un_plat_qu_ils_savent_faire() {
		var propositions = Set.of(
				new Proposition(new Plat("plat1"), chef1),
				new Proposition(new Plat("plat2"), chef2),
				new Proposition(new Plat("plat3"), chef3),
				new Proposition(new Plat("plat4"), chef4),
				new Proposition(new Plat("je sais pas faire donc exception"), chef5));

		assertThrows(IllegalArgumentException.class, () -> new Concours(jury1, jury2, jury3, propositions));
	}

	@Test
	void fin_du_concours() {
		Proposition proposition1 = new Proposition(new Plat("plat1"), chef1);
		Proposition proposition2 = new Proposition(new Plat("plat2"), chef2);
		Proposition proposition3 = new Proposition(new Plat("plat3"), chef3);
		Proposition proposition4 = new Proposition(new Plat("plat4"), chef4);
		Proposition proposition5 = new Proposition(new Plat("plat5"), chef5);

		Concours concours = new Concours(jury1, jury2, jury3, Set.of(
			proposition1,
			proposition2,
			proposition3,
			proposition4,
			proposition5
		));

		assertEquals(false, concours.estTermine());

		concours.noter(proposition1, 10);
		concours.noter(proposition2, 3);
		concours.noter(proposition3, 8);
		concours.noter(proposition4, 9);
		concours.noter(proposition5, 18);

		assertEquals(true, concours.estTermine());
	}
}
